Enum SpooledData

enum SpooledData

A wrapper for the two states of a SpooledTempFile. Either:

  1. An in-memory Cursor representing the state of the file.
  2. A temporary File.

Variants

InMemory(std::io::Cursor<Vec<u8>>)
OnDisk(std::fs::File)

Implementations

impl Debug for SpooledData

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for SpooledData

impl RefUnwindSafe for SpooledData

impl Send for SpooledData

impl Sync for SpooledData

impl Unpin for SpooledData

impl UnsafeUnpin for SpooledData

impl UnwindSafe for SpooledData

impl<T> Any for SpooledData

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SpooledData

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SpooledData

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for SpooledData

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for SpooledData

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SpooledData

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SpooledData

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>