Struct tempfile::Builder [−][src]
pub struct Builder<'a, 'b> { /* fields omitted */ }Expand description
Create a new temporary file or directory with custom parameters.
Implementations
Create a new Builder.
Examples
Create a named temporary file and write some data into it:
use tempfile::Builder;
let named_tempfile = Builder::new()
.prefix("my-temporary-note")
.suffix(".txt")
.rand_bytes(5)
.tempfile()?;
let name = named_tempfile
.path()
.file_name().and_then(OsStr::to_str);
if let Some(name) = name {
assert!(name.starts_with("my-temporary-note"));
assert!(name.ends_with(".txt"));
assert_eq!(name.len(), "my-temporary-note.txt".len() + 5);
}Create a temporary directory and add a file to it:
use tempfile::Builder;
let dir = Builder::new()
.prefix("my-temporary-dir")
.rand_bytes(5)
.tempdir()?;
let file_path = dir.path().join("my-temporary-note.txt");
let mut file = File::create(file_path)?;
writeln!(file, "Brian was here. Briefly.")?;
// By closing the `TempDir` explicitly, we can check that it has
// been deleted successfully. If we don't close it explicitly,
// the directory will still be deleted when `dir` goes out
// of scope, but we won't know whether deleting the directory
// succeeded.
drop(file);
dir.close()?;Set a custom filename prefix.
Path separators are legal but not advisable.
Default: .tmp.
Examples
let named_tempfile = Builder::new()
.prefix("my-temporary-note")
.tempfile()?;Set a custom filename suffix.
Path separators are legal but not advisable. Default: empty.
Examples
let named_tempfile = Builder::new()
.suffix(".txt")
.tempfile()?;Set the number of random bytes.
Default: 6.
Examples
let named_tempfile = Builder::new()
.rand_bytes(5)
.tempfile()?;Set the file to be opened in append mode.
Default: false.
Examples
let named_tempfile = Builder::new()
.append(true)
.tempfile()?;Create the named temporary file.
Security
See the security docs on NamedTempFile.
Resource leaking
See the resource leaking docs on NamedTempFile.
Errors
If the file cannot be created, Err is returned.
Examples
let tempfile = Builder::new().tempfile()?;Create the named temporary file in the specified directory.
Security
See the security docs on NamedTempFile.
Resource leaking
See the resource leaking docs on NamedTempFile.
Errors
If the file cannot be created, Err is returned.
Examples
let tempfile = Builder::new().tempfile_in("./")?;Attempts to make a temporary directory inside of env::temp_dir() whose
name will have the prefix, prefix. The directory and
everything inside it will be automatically deleted once the
returned TempDir is destroyed.
Resource leaking
See the resource leaking docs on TempDir.
Errors
If the directory can not be created, Err is returned.
Examples
use std::fs::File;
use std::io::Write;
use tempfile::Builder;
let tmp_dir = Builder::new().tempdir()?;Attempts to make a temporary directory inside of dir.
The directory and everything inside it will be automatically
deleted once the returned TempDir is destroyed.
Resource leaking
See the resource leaking docs on TempDir.
Errors
If the directory can not be created, Err is returned.
Examples
use std::fs::{self, File};
use std::io::Write;
use tempfile::Builder;
let tmp_dir = Builder::new().tempdir_in("./")?;Trait Implementations