[−][src]Struct tempfile::SpooledTempFile
An object that behaves like a regular temporary file, but keeps data in memory until it reaches a configured size, at which point the data is written to a temporary file on disk, and further operations use the file on disk.
Methods
impl SpooledTempFile[src]
ⓘImportant traits for SpooledTempFilepub fn new(max_size: usize) -> SpooledTempFile[src]
pub fn is_rolled(&self) -> bool[src]
Returns true if the file has been rolled over to disk.
pub fn roll(&mut self) -> Result<()>[src]
Rolls over to a file on disk, regardless of current size. Does nothing if already rolled over.
pub fn set_len(&mut self, size: u64) -> Result<(), Error>[src]